Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiextensionsV1beta1Client ¶
type ApiextensionsV1beta1Client struct {
// contains filtered or unexported fields
}
ApiextensionsV1beta1Client is used to interact with features provided by the apiextensions.k8s.io group.
func New ¶
func New(c rest.Interface) *ApiextensionsV1beta1Client
New creates a new ApiextensionsV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ApiextensionsV1beta1Client, error)
NewForConfig creates a new ApiextensionsV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ApiextensionsV1beta1Client
NewForConfigOrDie creates a new ApiextensionsV1beta1Client for the given config and panics if there is an error in the config.
func (*ApiextensionsV1beta1Client) CustomResourceDefinitions ¶
func (c *ApiextensionsV1beta1Client) CustomResourceDefinitions() CustomResourceDefinitionInterface
func (*ApiextensionsV1beta1Client) RESTClient ¶
func (c *ApiextensionsV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type ApiextensionsV1beta1Interface ¶
type ApiextensionsV1beta1Interface interface {
RESTClient() rest.Interface
CustomResourceDefinitionsGetter
}
type CustomResourceDefinitionExpansion ¶
type CustomResourceDefinitionExpansion interface{}
type CustomResourceDefinitionInterface ¶
type CustomResourceDefinitionInterface interface {
Create(*v1beta1.CustomResourceDefinition) (*v1beta1.CustomResourceDefinition, error)
Update(*v1beta1.CustomResourceDefinition) (*v1beta1.CustomResourceDefinition, error)
UpdateStatus(*v1beta1.CustomResourceDefinition) (*v1beta1.CustomResourceDefinition, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.CustomResourceDefinition, error)
List(opts v1.ListOptions) (*v1beta1.CustomResourceDefinitionList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.CustomResourceDefinition, err error)
CustomResourceDefinitionExpansion
}
CustomResourceDefinitionInterface has methods to work with CustomResourceDefinition resources.
type CustomResourceDefinitionsGetter ¶
type CustomResourceDefinitionsGetter interface {
CustomResourceDefinitions() CustomResourceDefinitionInterface
}
CustomResourceDefinitionsGetter has a method to return a CustomResourceDefinitionInterface. A group's client should implement this interface.
Source Files
¶
- apiextensions_client.go
- customresourcedefinition.go
- doc.go
- generated_expansion.go