Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIServiceExpansion ¶
type APIServiceExpansion interface{}
type APIServiceInterface ¶
type APIServiceInterface interface {
Create(*v1beta1.APIService) (*v1beta1.APIService, error)
Update(*v1beta1.APIService) (*v1beta1.APIService, error)
UpdateStatus(*v1beta1.APIService) (*v1beta1.APIService, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.APIService, error)
List(opts v1.ListOptions) (*v1beta1.APIServiceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.APIService, err error)
APIServiceExpansion
}
APIServiceInterface has methods to work with APIService resources.
type APIServicesGetter ¶
type APIServicesGetter interface {
APIServices() APIServiceInterface
}
APIServicesGetter has a method to return a APIServiceInterface. A group's client should implement this interface.
type ApiregistrationV1beta1Client ¶
type ApiregistrationV1beta1Client struct {
// contains filtered or unexported fields
}
ApiregistrationV1beta1Client is used to interact with features provided by the apiregistration.k8s.io group.
func New ¶
func New(c rest.Interface) *ApiregistrationV1beta1Client
New creates a new ApiregistrationV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ApiregistrationV1beta1Client, error)
NewForConfig creates a new ApiregistrationV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ApiregistrationV1beta1Client
NewForConfigOrDie creates a new ApiregistrationV1beta1Client for the given config and panics if there is an error in the config.
func (*ApiregistrationV1beta1Client) APIServices ¶
func (c *ApiregistrationV1beta1Client) APIServices() APIServiceInterface
func (*ApiregistrationV1beta1Client) RESTClient ¶
func (c *ApiregistrationV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type ApiregistrationV1beta1Interface ¶
type ApiregistrationV1beta1Interface interface {
RESTClient() rest.Interface
APIServicesGetter
}
Source Files
¶
- apiregistration_client.go
- apiservice.go
- doc.go
- generated_expansion.go