Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuditSinkExpansion ¶
type AuditSinkExpansion interface{}
type AuditSinkInterface ¶
type AuditSinkInterface interface {
Create(ctx context.Context, auditSink *v1alpha1.AuditSink, opts v1.CreateOptions) (*v1alpha1.AuditSink, error)
Update(ctx context.Context, auditSink *v1alpha1.AuditSink, opts v1.UpdateOptions) (*v1alpha1.AuditSink, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.AuditSink, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.AuditSinkList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.AuditSink, err error)
AuditSinkExpansion
}
AuditSinkInterface has methods to work with AuditSink resources.
type AuditSinksGetter ¶
type AuditSinksGetter interface {
AuditSinks() AuditSinkInterface
}
AuditSinksGetter has a method to return a AuditSinkInterface. A group's client should implement this interface.
type AuditregistrationV1alpha1Client ¶
type AuditregistrationV1alpha1Client struct {
// contains filtered or unexported fields
}
AuditregistrationV1alpha1Client is used to interact with features provided by the auditregistration.k8s.io group.
func New ¶
func New(c rest.Interface) *AuditregistrationV1alpha1Client
New creates a new AuditregistrationV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*AuditregistrationV1alpha1Client, error)
NewForConfig creates a new AuditregistrationV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *AuditregistrationV1alpha1Client
NewForConfigOrDie creates a new AuditregistrationV1alpha1Client for the given config and panics if there is an error in the config.
func (*AuditregistrationV1alpha1Client) AuditSinks ¶
func (c *AuditregistrationV1alpha1Client) AuditSinks() AuditSinkInterface
func (*AuditregistrationV1alpha1Client) RESTClient ¶
func (c *AuditregistrationV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type AuditregistrationV1alpha1Interface ¶
type AuditregistrationV1alpha1Interface interface {
RESTClient() rest.Interface
AuditSinksGetter
}
Source Files
¶
- auditregistration_client.go
- auditsink.go
- doc.go
- generated_expansion.go