persistentvolume

package
v0.0.0-...-d88c8b5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2021 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func VisitPVSecretNames

func VisitPVSecretNames(pv *corev1.PersistentVolume, visitor Visitor) bool

VisitPVSecretNames invokes the visitor function with the name of every secret referenced by the PV spec. If visitor returns false, visiting is short-circuited. Returns true if visiting completed, false if visiting was short-circuited.

Types

type Visitor

type Visitor func(namespace, name string, kubeletVisible bool) (shouldContinue bool)

Visitor is called with each object's namespace and name, and returns true if visiting should continue

Source Files

  • util.go

Jump to