Documentation
¶
Overview ¶
Package service provides the Registry interface and its RESTStorage implementation for storing Service api objects.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProxyREST ¶
type ProxyREST struct {
Redirector rest.Redirector
ProxyTransport http.RoundTripper
}
ProxyREST implements the proxy subresource for a Service
func (*ProxyREST) Connect ¶
func (r *ProxyREST) Connect(ctx context.Context, id string, opts runtime.Object, responder rest.Responder) (http.Handler, error)
Connect returns a handler for the service proxy
func (*ProxyREST) ConnectMethods ¶
ConnectMethods returns the list of HTTP methods that can be proxied
func (*ProxyREST) New ¶
New returns an empty service resource
type Strategy ¶
type Strategy interface {
rest.RESTCreateUpdateStrategy
rest.RESTExportStrategy
}
func NewServiceStatusStrategy ¶
NewServiceStatusStrategy creates a status strategy for the provided base strategy.
Source Files
¶
- doc.go
- proxy.go
- strategy.go
Click to show internal directories.
Click to hide internal directories.